@@ -1,5 +1,6 @@
 from django.core.exceptions import NON_FIELD_ERRORS
 from django.forms.forms import BaseForm
+from django.forms.models import BaseModelForm, construct_instance, model_to_dict
 from django.forms.widgets import MediaDefiningClass
 from django.forms.utils import ErrorDict, ErrorList, RenderableMixin
 from django.utils.datastructures import MultiValueDict
@@ -225,6 +226,40 @@ class BaseFormCollection(HolderMixin, RenderableMixin):
             renderer = FormRenderer()
         return super().render(template_name, context, renderer)
 
+    def model_to_dict(self, main_object):
+        """
+        Create initial data from a main object. This then is used to fill the initial data from all its child
+        collections and forms.
+        Forms which do not correspond to the model given by the main object, are themselves responsible to
+        access the proper referenced models.
+        """
+        object_data = {}
+        for name, holder in self.declared_holders.items():
+            if callable(getattr(holder, 'model_to_dict', None)):
+                object_data[name] = holder.model_to_dict(main_object)
+            elif isinstance(holder, BaseModelForm):
+                opts = holder._meta
+                object_data[name] = model_to_dict(main_object, opts.fields, opts.exclude)
+            else:
+                object_data[name] = model_to_dict(main_object)
+        return object_data
+
+    def construct_instance(self, main_object, cleaned_data):
+        """
+        Construct the main object and its related objects from the nested dictionary of cleaned data.
+        Forms which do not correspond to the model given by the main object, are responsible themselves
+        to store the corresponding data inside their related models.
+        """
+        for name, holder in self.declared_holders.items():
+            if callable(getattr(holder, 'construct_instance', None)):
+                holder.construct_instance(main_object, self.cleaned_data[name])
+            elif isinstance(holder, BaseModelForm):
+                opts = holder._meta
+                holder.cleaned_data = self.cleaned_data[name]
+                holder.instance = main_object
+                construct_instance(holder, main_object, opts.fields, opts.exclude)
+                holder.save()
+
     __str__ = render
     __html__ = render
 
