@@ -4,12 +4,19 @@ from django.http.response import HttpResponseBadRequest, JsonResponse
 from django.utils.functional import cached_property
 from django.views.generic.base import ContextMixin, TemplateResponseMixin, View
 from django.views.generic.edit import FormView as GenericFormView
+from django.views.generic.detail import SingleObjectMixin
 
 from formset.upload import FileUploadMixin
 from formset.widgets import Selectize, DualSelector
 
 
 class IncompleSelectResponseMixin:
+    """
+    Add this mixin class to views classes using forms with incomplete fields. These fields
+    usually are of type ChoiceField referring to a foreign model and using one of the widgets
+    :class:`formset.widgets.Selectize`, :class:`formset.widgets.SelectizeMultiple` or
+    :class:`formset.widgets.DualSelector`.
+    """
     def get(self, request, **kwargs):
         if request.accepts('application/json') and 'field' in request.GET:
             if 'query' in request.GET or 'offset' in request.GET:
@@ -47,7 +54,22 @@ class IncompleSelectResponseMixin:
         return JsonResponse(data)
 
 
-class FormViewMixin:
+class FormsetResponseMixin:
+    @cached_property
+    def _request_body(self):
+        if self.request.content_type == 'application/json':
+            return json.loads(self.request.body)
+
+    def get_extra_data(self):
+        """
+        When submitting a form, one can additionally add extra parameters via the button's ``submit()`` action.
+        Use this method to access that extra data.
+        """
+        if self._request_body:
+            return self._request_body.get('_extra')
+
+
+class FormViewMixin(FormsetResponseMixin):
     def get_success_url(self):
         """
         In **django-formset**, the success_url may be None and set inside the templates.
@@ -73,19 +95,6 @@ class FormViewMixin:
         field_name = path.split('.')[-1]
         return self.form_class.base_fields[field_name]
 
-    def get_extra_data(self):
-        """
-        When submitting a form, one can additionally add extra parameters via the button's ``submit()`` action.
-        Use this method to access that extra data.
-        """
-        if self._request_body:
-            return self._request_body.get('_extra')
-
-    @cached_property
-    def _request_body(self):
-        if self.request.content_type == 'application/json':
-            return json.loads(self.request.body)
-
 
 class FormView(IncompleSelectResponseMixin, FileUploadMixin, FormViewMixin, GenericFormView):
     """
@@ -116,14 +125,11 @@ class FormView(IncompleSelectResponseMixin, FileUploadMixin, FormViewMixin, Gene
     """
 
 
-class FormCollectionViewMixin(ContextMixin):
+class FormCollectionViewMixin(FormsetResponseMixin):
     collection_class = None
     success_url = None
     initial = {}
 
-    def __init__(self, **kwargs):
-        super().__init__(**kwargs)
-
     def get(self, request, *args, **kwargs):
         """Handle GET requests: instantiate blank versions of the forms in the collection."""
         return self.render_to_response(self.get_context_data())
@@ -170,5 +176,26 @@ class FormCollectionViewMixin(ContextMixin):
         return JsonResponse(form_collection.errors, status=422, safe=False)
 
 
-class FormCollectionView(IncompleSelectResponseMixin, FileUploadMixin, FormCollectionViewMixin, TemplateResponseMixin, View):
+class FormCollectionView(IncompleSelectResponseMixin, FileUploadMixin, FormCollectionViewMixin, ContextMixin, TemplateResponseMixin, View):
     pass
+
+
+class EditCollectionView(IncompleSelectResponseMixin, FileUploadMixin, FormCollectionViewMixin, SingleObjectMixin, TemplateResponseMixin, View):
+    def get(self, request, *args, **kwargs):
+        self.object = self.get_object()
+        return super().get(request, *args, **kwargs)
+
+    def post(self, request, *args, **kwargs):
+        self.object = self.get_object()
+        return super().post(request, *args, **kwargs)
+
+    def get_initial(self):
+        initial = super().get_initial()
+        if self.object:
+            collection_class = self.get_collection_class()
+            initial.update(collection_class().model_to_dict(self.object))
+        return initial
+
+    def form_collection_valid(self, form_collection):
+        form_collection.construct_instance(self.object, form_collection.cleaned_data)
+        return super().form_collection_valid(form_collection)
